@@ -133,11 +133,7 @@ def replay(apply_vars: List[str], where_clause: str, path: str):
     path: `train_rnn.py` or such denoting main python script
     """
     assert Path(path).suffix == ".py"
-    df = (
-        full_pivot(facts)
-        if facts is not None
-        else full_pivot(log_records(skip_unpack=True))
-    )
+    df = full_pivot(log_records(skip_unpack=True))
     assert df is not None
 
     loglvl = get_dims(pivot_vars, apply_vars)
@@ -167,7 +163,7 @@ def replay(apply_vars: List[str], where_clause: str, path: str):
         versions = dp_schedule["vid"].drop_duplicates()
         display(dp_schedule)
         print(
-            f"Continue replaying {len(versions)} versions at DATA_PREP level for {'{:.2f}'.format(sum(dp_schedule['seconds']))} seconds?"
+            f"Continue replaying {len(versions)} versions at DATA_PREP level for {'{:.2f}'.format(3 * len(versions) + sum(dp_schedule['seconds']))} seconds?"
         )
         res = input("Continue [Y/n]? ")
         if res.strip().lower() != "n":
